import React, { useState, lazy, Suspense } from 'react';
import { Star, Clock, DollarSign, ThumbsUp, Car } from 'lucide-react';
import { useNavigate } from 'react-router-dom';
import { supabase } from './lib/supabase';
import { createContact } from './lib/gohighlevel';
import { Image } from './components/Image';
import { getImageUrl } from './lib/images';

// Lazy load the map component
const LocationMap = lazy(() => import('./components/LocationMap'));

function App() {
  const navigate = useNavigate();
  const [formData, setFormData] = useState({
    firstName: '',
    lastName: '',
    phone: '',
    email: '',
    vehicle: ''
  });
  const [isSubmitting, setIsSubmitting] = useState(false);
  const [submitError, setSubmitError] = useState<string | null>(null);

  const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const { name, value } = e.target;
    setFormData(prev => ({
      ...prev,
      [name]: value
    }));
    // Clear error when user starts typing
    if (submitError) setSubmitError(null);
  };

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    
    if (isSubmitting) return;
    
    setIsSubmitting(true);
    setSubmitError(null);

    try {
      await createContact({
        email: formData.email,
        firstName: formData.firstName,
        lastName: formData.lastName,
        phone: formData.phone,
        vehicle: formData.vehicle
      });

      // Only navigate on success
      navigate('/thank-you');
    } catch (error) {
      console.error('Error submitting form:', error);
      setSubmitError(error instanceof Error ? error.message : 'There was an error submitting your form. Please try again or contact support.');
    } finally {
      setIsSubmitting(false);
    }
  };

  return (
    <div className="min-h-screen bg-white flex flex-col">
      {/* Header */}
      <header className="py-1 bg-white">
        <div className="container mx-auto px-4 flex justify-center items-center">
          <Image 
            imageName="logo"
            className="h-6 md:h-10 w-auto object-contain"
            loading="eager"
            decoding="async"
          />
        </div>
      </header>

      {/* Hero Section with Integrated Form */}
      <section className="relative flex-1 flex items-center justify-center py-3">
        <div 
          className="absolute inset-0 z-0 bg-cover bg-center bg-no-repeat"
          style={{
            backgroundImage: `url(${getImageUrl('hero')})`,
            willChange: 'transform'
          }}
        >
          <div className="absolute inset-0 bg-black/60"></div>
        </div>
        
        <div className="container mx-auto px-4 relative z-10">
          <div className="max-w-4xl mx-auto text-center">
            <div className="bg-black/25 backdrop-blur-sm p-6 rounded-lg inline-block mb-8">
              <h1 className="text-3xl md:text-4xl font-bold mb-4 md:mb-3 mt-0 text-white">
                Get <span className="text-[#F7B614]">$20 Off</span> Your Oil Change
              </h1>
              <p className="text-base md:text-xl text-white font-normal md:font-bold mb-4 md:mb-3">
                Experience the <span className="text-[#F7B614]">fastest oil change</span> in Sherman—<br className="hidden md:block" />
                no upsells, no hidden fees, just oil.
              </p>
              <div className="flex justify-center items-center gap-1 mb-1">
                {[...Array(5)].map((_, i) => (
                  <Star key={i} className="w-4 h-4 fill-[#F7B614] text-[#F7B614]" />
                ))}
              </div>
              <p className="text-white text-xs md:text-base">
                <span className="font-bold">4.6</span> based on<br className="hidden md:block" />
                <span className="font-bold">100+ reviews</span>
              </p>
            </div>

            {/* Form */}
            <div className="max-w-md mx-auto">
              <form onSubmit={handleSubmit} className="bg-white rounded-lg shadow-lg p-8">
                <div className="flex flex-col space-y-4">
                  <input
                    type="text"
                    id="firstName"
                    name="firstName"
                    required
                    placeholder="First Name*"
                    value={formData.firstName}
                    onChange={handleChange}
                    className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-[#F7B614] focus:border-transparent placeholder-gray-400"
                  />
                  <input
                    type="text"
                    id="lastName"
                    name="lastName"
                    required
                    placeholder="Last Name*"
                    value={formData.lastName}
                    onChange={handleChange}
                    className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-[#F7B614] focus:border-transparent placeholder-gray-400"
                  />
                  <input
                    type="tel"
                    id="phone"
                    name="phone"
                    required
                    placeholder="Phone Number*"
                    value={formData.phone}
                    onChange={handleChange}
                    className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-[#F7B614] focus:border-transparent placeholder-gray-400"
                  />
                  <input
                    type="email"
                    id="email"
                    name="email"
                    required
                    placeholder="Email*"
                    value={formData.email}
                    onChange={handleChange}
                    className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-[#F7B614] focus:border-transparent placeholder-gray-400"
                  />
                  <input
                    type="text"
                    id="vehicle"
                    name="vehicle"
                    required
                    placeholder="Vehicle Make & Model*"
                    value={formData.vehicle}
                    onChange={handleChange}
                    className="w-full px-4 py-3 border border-gray-300 rounded-lg focus:ring-2 focus:ring-[#F7B614] focus:border-transparent placeholder-gray-400"
                  />
                </div>
                
                <p className="text-xs text-gray-500 mt-6 mb-4 text-center">
                  By submitting this form you agree to receive text messages and emails from Costa Oils.
                </p>

                {submitError && (
                  <div className="mb-4 p-3 bg-red-100 text-red-700 rounded-lg text-sm">
                    {submitError}
                  </div>
                )}
                
                <button
                  type="submit"
                  disabled={isSubmitting}
                  className={`w-full bg-[#F7B614] text-black font-bold py-4 px-8 rounded-lg transition-colors ${
                    isSubmitting ? 'opacity-75 cursor-not-allowed' : 'hover:bg-[#E5A912]'
                  }`}
                >
                  {isSubmitting ? 'Submitting...' : 'Get $20 Off Coupon Now!'}
                </button>
              </form>
            </div>
          </div>
        </div>
      </section>

      {/* Features Section */}
      <section className="bg-white py-16">
        <div className="container mx-auto px-4">
          <div className="max-w-4xl mx-auto">
            <h2 className="text-3xl md:text-4xl font-bold text-center mb-4">
              Fast, Friendly & Affordable – 10‑Minute Oil Change with $20 Off
            </h2>
            <p className="text-xl text-gray-600 text-center mb-12">
              Say goodbye to long waits and pricey upsells. Enjoy a quick, no-hassle oil change that saves you time and money.
            </p>

            {/* Service Overview */}
            <div className="grid md:grid-cols-2 gap-8 md:gap-12 items-center mb-16">
              <div className="order-2 md:order-1">
                <Image
                  imageName="technician"
                  alt="A friendly Costa Oil technician works on a vehicle"
                  className="rounded-lg shadow-lg w-full h-auto object-cover"
                  loading="lazy"
                />
              </div>
              <div className="space-y-6 order-1 md:order-2">
                <p className="text-gray-700">
                  Are you tired of spending your afternoon at the shop for a simple oil change? At Costa Oil, we've redefined the oil change experience with a swift 10‑minute service that gets you back on the road fast. No more waiting rooms or pushy sales pitches – just top‑notch service at a price you'll love. And with our $20 off coupon for first‑time customers, there's never been a better time to give us a try.
                </p>
                <ul className="space-y-4">
                  <li className="flex items-start gap-3">
                    <Clock className="w-6 h-6 text-[#F7B614] flex-shrink-0 mt-1" />
                    <div>
                      <strong className="block text-gray-900">Lightning-Fast Service:</strong>
                      <span className="text-gray-700">Stay in your car and relax – we'll finish your oil change in about 10 minutes, no appointment needed.</span>
                    </div>
                  </li>
                  <li className="flex items-start gap-3">
                    <ThumbsUp className="w-6 h-6 text-[#F7B614] flex-shrink-0 mt-1" />
                    <div>
                      <strong className="block text-gray-900">No Upsell Guarantee:</strong>
                      <span className="text-gray-700">You get only what you need. Our techs won't try to push extra services or parts you didn't ask for.</span>
                    </div>
                  </li>
                  <li className="flex items-start gap-3">
                    <DollarSign className="w-6 h-6 text-[#F7B614] flex-shrink-0 mt-1" />
                    <div>
                      <strong className="block text-gray-900">Affordable Pricing:</strong>
                      <span className="text-gray-700">An oil change at Costa Oil costs less than at the big shops and dealerships, and your $20 coupon makes it an even better deal.</span>
                    </div>
                  </li>
                  <li className="flex items-start gap-3">
                    <Car className="w-6 h-6 text-[#F7B614] flex-shrink-0 mt-1" />
                    <div>
                      <strong className="block text-gray-900">Convenient & Friendly:</strong>
                      <span className="text-gray-700">We're a local business that treats customers like neighbors. Expect a courteous, professional team and an easy, drive-thru experience every time.</span>
                    </div>
                  </li>
                </ul>
              </div>
            </div>

            {/* Customer Reviews */}
            <div className="bg-gray-50 rounded-lg p-6 md:p-8 mb-16">
              <div className="grid md:grid-cols-2 gap-6 md:gap-8 items-center">
                <div className="bg-white rounded-lg p-4 shadow-md">
                  <div className="flex items-center gap-3 mb-4">
                    <div className="w-12 h-12 rounded-full bg-gray-200 overflow-hidden">
                      <img
                        src="https://images.unsplash.com/photo-1508214751196-bcfd4ca60f91?auto=format&fit=crop&w=200&q=80"
                        alt="Darla H."
                        className="w-full h-full object-cover"
                      />
                    </div>
                    <div>
                      <h3 className="font-semibold text-lg">Darla H.</h3>
                      <div className="flex items-center gap-1">
                        {[...Array(5)].map((_, i) => (
                          <Star key={i} className="w-4 h-4 fill-[#F7B614] text-[#F7B614]" />
                        ))}
                      </div>
                    </div>
                  </div>
                  <p className="text-gray-700">
                    I'm a new customer and I'm so happy I discovered this place! They are very good. Willing to go the extra mile to take care of their customers. Waiting in my car was very nice. Other places were booked solid today. I drove right in. Yea! The last place I used actually torked my filter. A big No-No!! I have to take it back to the last place to get them to remove my filter as this might damage my car.
                  </p>
                  <p className="text-gray-500 text-sm mt-2">1 month ago</p>
                </div>
                <div>
                  <p className="text-gray-700 mb-4">
                    Our customers love the Costa Oil difference. Many have left us 5‑star reviews for our speed, value, and honest approach. We're proud to be a trusted part of the community, making oil changes easier for everyone.
                  </p>
                  <div className="flex items-center gap-1">
                    {[...Array(5)].map((_, i) => (
                      <Star key={i} className="w-5 h-5 fill-[#F7B614] text-[#F7B614]" />
                    ))}
                  </div>
                </div>
              </div>
            </div>

            {/* Call to Action */}
            <div className="text-center">
              <div className="mb-8 max-w-md mx-auto">
                <Image
                  imageName="coupon"
                  className="rounded-lg shadow-lg w-full h-auto object-contain"
                  loading="lazy"
                />
              </div>
              <p className="text-gray-700 max-w-2xl mx-auto mb-8">
                Ready to save time and money? Claim your $20 off coupon now by submitting your info below. It only takes a minute, and you'll instantly receive your coupon for a quick, hassle-free oil change at your nearest Costa Oil location. Don't wait – this is your chance to skip the line, avoid the upsell, and get a better oil change for less!
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* Location Section */}
      <section className="bg-gray-50 py-16">
        <div className="container mx-auto px-4">
          <div className="max-w-4xl mx-auto">
            <div className="text-center mb-12">
              <h2 className="text-3xl md:text-4xl font-bold mb-4">
                Come See Us—No Appointment Needed
              </h2>
              <p className="text-xl md:text-2xl text-[#F7B614] font-bold italic">
                WE'RE THAT FAST!
              </p>
            </div>
            
            <div className="grid md:grid-cols-2 gap-8 items-start">
              <div className="bg-white rounded-lg overflow-hidden shadow-lg h-[400px]">
                <Suspense fallback={
                  <div className="w-full h-full bg-gray-100 animate-pulse flex items-center justify-center">
                    <p className="text-gray-500">Loading map...</p>
                  </div>
                }>
                  <LocationMap />
                </Suspense>
              </div>
              
              <div className="bg-white rounded-lg shadow-lg p-8">
                <div className="space-y-8">
                  <div className="text-center md:text-left">
                    <h3 className="text-2xl font-bold mb-3">Address</h3>
                    <p className="text-gray-700 text-lg">
                      1119 S Sam Rayburn Fwy<br />
                      Sherman, TX 75090
                    </p>
                  </div>
                  
                  <div className="text-center md:text-left">
                    <h3 className="text-2xl font-bold mb-3">Store Hours</h3>
                    <p className="text-gray-700 text-lg">
                      Monday - Saturday: 8am - 5pm<br />
                      Sunday: Closed
                    </p>
                  </div>

                  <div className="text-center md:text-left">
                    <h3 className="text-2xl font-bold mb-3">Contact</h3>
                    <p className="text-gray-700 text-lg">
                      Phone: (903) 771-0002
                    </p>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>
    </div>
  );
}

export default App;